@@ -12,8 +12,8 @@ class WatchmenNotebook(BaseModel):
 
 
 
-
-test = WatchmenNotebook(name="A",storageLocation="")
-print(test)
+#
+# test = WatchmenNotebook(name="A",storageLocation="")
+# print(test.json())
 
 
