@@ -11,8 +11,8 @@ class WatchmenClient(object):
         else:
             self.token = os.environ.get('TOKEN')
 
-    def load_dataset(self, name):
-        return load_dataset_by_name(self.token, name)
+    def load_dataset(self, name,dataframe_type="pandas"):
+        return load_dataset_by_name(self.token, name,dataframe_type)
 
     def register_notebook(self, storage_type="file"):
         notebook = get_notebook(storage_type)
@@ -26,9 +26,6 @@ class WatchmenClient(object):
         pass
 
 
-
-
-
     def register_model(self):
         pass
 
