@@ -4,6 +4,7 @@ import requests
 
 from ml_sdk.ml.model.notebook import WatchmenNotebook
 
+##TODO set url to env
 local_env_url = "http://localhost:8000"
 
 
@@ -20,7 +21,7 @@ def build_indicators(columns):
     return indicators
 
 
-def load_dataset_by_name(token, name):
+def load_dataset_by_name(token, name,dataframe_type):
     response = requests.get(local_env_url + "/subject/name", params={"name": name}, headers=build_headers(token))
     subject = response.json()
     ## TODO  columns type
@@ -36,5 +37,8 @@ def load_dataset_by_name(token, name):
 
 
 def push_notebook_to_watchmen(notebook:WatchmenNotebook,token):
-    response = requests.post(local_env_url + "/notebook", data=notebook.json(),
-                             headers=build_headers(token))
\ No newline at end of file
+    response =  requests.post(local_env_url + "/notebook", data=notebook.json(),
+                             headers=build_headers(token))
+    print(response)
+    return response
+
